import { Component, Prop, Vue, Watch } from 'vue-property-decorator';
import moment from 'moment';
import { Measure, TextMeasureConfig, Measurement, TextMeasurementMeta } from '@/models';
import { byTimestampComparator } from '@/util';

const YEAR_START = moment().startOf('year');

@Component
export class TextSummary extends Vue {
  @Prop() private measure!: Measure<TextMeasureConfig>;
  @Prop() private measurements!: Array<Measurement<TextMeasurementMeta>>;

  private top5: Array<Measurement<TextMeasurementMeta>> = [];
  private withinLastYear: boolean = true;

  @Watch('measurements')
  private onMeasurementsChanged() {
    this.top5 = this.measurements
      .slice(0)
      .sort(byTimestampComparator)
      .slice(0, 5);

    this.withinLastYear = this.top5.every((entry) => YEAR_START.isBefore(entry.timestamp));
  }

  private formatDate(ts: Date) {
    if (this.withinLastYear) { return moment(ts).format('MMM. Do'); }
    else { return moment(ts).format('YYYY-MM-DD'); }
  }

}

export default TextSummary;
